==> sql-generator-1.1.1-src.zip: sql-generator-1.1.1-src/src/org/sql/condition/Condition.java <==
/*
 * SQL Generator
 * 
 * Copyright (C) 2005 Satoshi Nagashiba, All Rights Reserved.
 */
package org.sql.condition;

import org.sql.comparison.AbstractComparison;
import org.sql.comparison.Comparison;


/**
 * ǗNX.
 * 
 * <P>
 * <ul>
 *     <li>WHERE ` ANDŔrݒ肷ꍇ́Aand\bhgp܂B<br>
 *     <br>
 *     <b>Java\[XTv</b><br>
 *     <table><tr><td class="SampleCode">
 *         j<font color="blue">SELECT * FROM TABLE1 WHERE COLUMN1 = '' AND COLUMN2 = ''</font><br>
 *         <br>
 *         @Condition condition = new Condition();<br>
 *         @condition.and(Comparisons.eq("COLUMN1", ""));<br>
 *         @condition.and(Comparisons.eq("COLUMN2", ""));<br>
 *         @<br>
 *         @SelectSql sql = new SelectSql("TABLE1", new SelectColumn());
 *         @sql.setCondition(condition);
 *     </td></tr></table>
 *     <br>
 *     <br>
 *     <li>WHERE ` ORŔrݒ肷ꍇ́Aor\bhgp܂B<br>
 *     <br>
 *     <b>Java\[XTv</b><br>
 *     <table><tr><td class="SampleCode">
 *         j<font color="blue">SELECT * FROM TABLE1 WHERE COLUMN1 = '' OR COLUMN2 = ''</font><br>
 *         @<br>
 *         @Condition condition = new Condition();<br>
 *         @condition.or(Comparisons.eq("COLUMN1", ""));<br>
 *         @condition.or(Comparisons.eq("COLUMN2", ""));<br>
 *         @<br>
 *         @SelectSql sql = new SelectSql("TABLE1", new SelectColumn());
 *         @sql.setCondition(condition);
 *     </td></tr></table>
 * </ul>
 * <P>
 *
 * @author S.Nagashiba
 */
public final class Condition extends AbstractBindCondition {

	/**
	 * RXgN^
	 */
	public Condition() {
		super();
	}
	
	/**
	 * 𐶐
	 * @param comparison r
	 * @param condition WHEREAANDAOR
	 */
	protected void createCondition(Comparison comparison, String condition) {
	    //rɗO΁ÃNXɗOݒ肵
	    if (((AbstractComparison) comparison).getException() != null) {
	        this.setException(((AbstractComparison) comparison).getException());
	        return;
	    }
	    if (super.isEmpty()) {
	        super.setCondition(WHERE , comparison);
	    }
	    else {
	        super.setCondition(condition, comparison);
	    }
	}
}

==> sql-generator-1.1.3-src.zip: sql-generator-1.1.3-src/src/org/sql/condition/Condition.java <==
/*
 * SQL Generator
 * 
 * Copyright (C) 2005 Satoshi Nagashiba, All Rights Reserved.
 */
package org.sql.condition;

import org.sql.comparison.BaseComparison;
import org.sql.comparison.Comparison;


/**
 * ǗNX.
 * 
 * <P>
 * <ul>
 *     <li>WHERE ` ANDŔrݒ肷ꍇ́Aand\bhgp܂B<br>
 *     <br>
 *     <b>Java\[XTv</b><br>
 *     <table><tr><td class="SampleCode">
 *         j<font color="blue">SELECT * FROM TABLE1 WHERE COLUMN1 = '' AND COLUMN2 = ''</font><br>
 *         <br>
 *         @Condition condition = new Condition();<br>
 *         @condition.and(Comparisons.eq("COLUMN1", ""));<br>
 *         @condition.and(Comparisons.eq("COLUMN2", ""));<br>
 *         @<br>
 *         @SelectSql sql = new SelectSql("TABLE1", new SelectColumn());
 *         @sql.setCondition(condition);
 *     </td></tr></table>
 *     <br>
 *     <br>
 *     <li>WHERE ` ORŔrݒ肷ꍇ́Aor\bhgp܂B<br>
 *     <br>
 *     <b>Java\[XTv</b><br>
 *     <table><tr><td class="SampleCode">
 *         j<font color="blue">SELECT * FROM TABLE1 WHERE COLUMN1 = '' OR COLUMN2 = ''</font><br>
 *         @<br>
 *         @Condition condition = new Condition();<br>
 *         @condition.or(Comparisons.eq("COLUMN1", ""));<br>
 *         @condition.or(Comparisons.eq("COLUMN2", ""));<br>
 *         @<br>
 *         @SelectSql sql = new SelectSql("TABLE1", new SelectColumn());
 *         @sql.setCondition(condition);
 *     </td></tr></table>
 * </ul>
 * <P>
 *
 * @author <a href="mailto:nagashiba.satoshi@opcybe.co.jp">Satoshi Nagashiba</a>
 * @version $Revision: 1.8 $ $Date: 2006/04/08 08:48:16 $
 */
public final class Condition extends BaseBindCondition {

	/**
	 * RXgN^
	 */
	public Condition() {
		super();
	}
	
	/**
	 * 𐶐
	 * @param comparison r
	 * @param condition WHEREAANDAOR
	 */
	protected void createCondition(Comparison comparison, String condition) {
	    //rɗO΁ÃNXɗOݒ肵
	    if (((BaseComparison) comparison).getException() != null) {
	        this.setException(((BaseComparison) comparison).getException());
	        return;
	    }
	    if (super.isEmpty()) {
	        super.setCondition(WHERE , comparison);
	    }
	    else {
	        super.setCondition(condition, comparison);
	    }
	}
}
